@@ -5,7 +5,7 @@ from pathlib import Path
 from typing import List, Tuple
 
 import click
-from delfino.decorators import files_folders_option
+from delfino.decorators import files_folders_option, pass_args
 from delfino.execution import OnError, run
 from delfino.models import AppContext
 from delfino.terminal_output import print_header
@@ -16,7 +16,15 @@ from delfino_core.config import CorePluginConfig, pass_plugin_app_context
 from delfino_core.utils import ensure_reports_dir
 
 
-def _run_typecheck(paths: List[Path], strict: bool, reports_file: Path, summary_only: bool, mypypath: Path):
+def _run_typecheck(
+    paths: List[Path],
+    strict: bool,
+    reports_file: Path,
+    summary_only: bool,
+    mypypath: Path,
+    print_second_level_headers: bool,
+    passed_args: Tuple[str, ...],
+):
     args: ArgsList = [
         "mypy",
         "--show-column-numbers",
@@ -30,6 +38,7 @@ def _run_typecheck(paths: List[Path], strict: bool, reports_file: Path, summary_
         "silent",
         "--junit-xml",
         reports_file,
+        *passed_args,
     ]
 
     if strict:
@@ -40,6 +49,9 @@ def _run_typecheck(paths: List[Path], strict: bool, reports_file: Path, summary_
     if summary_only:
         args.extend(["|", "tail", "-n", "1"])
 
+    if print_second_level_headers:
+        print_header(f"{'Strict' if strict else 'Optional'} types", level=2, icon="⚠️" if strict else "ℹ️")
+
     run(args, env_update_path={"MYPYPATH": mypypath}, on_error=OnError.ABORT)
 
 
@@ -56,8 +68,14 @@ def is_path_relative_to_paths(path: Path, paths: List[Path]) -> bool:
 @click.command()
 @click.option("--summary-only", is_flag=True, help="Suppress error messages and show only summary error count.")
 @files_folders_option
+@pass_args
 @pass_plugin_app_context
-def typecheck(app_context: AppContext[CorePluginConfig], summary_only: bool, files_folders: Tuple[str, ...]):
+def typecheck(
+    app_context: AppContext[CorePluginConfig],
+    passed_args: Tuple[str, ...],
+    summary_only: bool,
+    files_folders: Tuple[str, ...],
+):
     """Run type checking on source code.
 
     A non-zero return code from this task indicates invalid types were discovered.
@@ -83,4 +101,12 @@ def typecheck(app_context: AppContext[CorePluginConfig], summary_only: bool, fil
         report_filepath = (
             plugin_config.reports_directory / "typecheck" / f"junit-{'strict' if force_typing else 'nonstrict'}.xml"
         )
-        _run_typecheck(list(group), force_typing, report_filepath, summary_only, plugin_config.sources_directory)
+        _run_typecheck(
+            list(group),
+            force_typing,
+            report_filepath,
+            summary_only,
+            plugin_config.sources_directory,
+            bool(strict_paths),
+            passed_args,
+        )
